This project uses Trusted Publishing:

* Bump version in `pyproject.toml`
* Run `uv sync`
* Commit and tag new version
* Publish the release on GitHub with CHANGELOG

Now a new version will be automatically pushed to PyPi.